@@ -2,23 +2,28 @@ from __future__ import annotations
 
 import datetime
 import logging
+import textwrap
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from typing import Optional, List, Sequence
 
 import pandas as pd
 
-from metricflow.cli.models import Dimension, Metric
-from metricflow.cli.models import Materialization
+from metricflow.configuration.constants import CONFIG_DWH_SCHEMA
+from metricflow.configuration.yaml_handler import YamlFileHandler
 from metricflow.dataflow.builder.dataflow_plan_builder import DataflowPlanBuilder
 from metricflow.dataflow.dataflow_plan import DataflowPlan
 from metricflow.dataflow.sql_table import SqlTable
 from metricflow.dataset.convert_data_source import DataSourceToDataSetConverter
+from metricflow.engine.models import Dimension, Materialization, Metric
+from metricflow.engine.time_source import ServerTimeSource
+from metricflow.engine.utils import build_user_configured_model_from_config
 from metricflow.execution.execution_plan import ExecutionPlan, SqlQuery
 from metricflow.execution.execution_plan_to_text import execution_plan_to_text
 from metricflow.execution.executor import SequentialPlanExecutor
 from metricflow.model.semantic_model import SemanticModel
 from metricflow.object_utils import pformat_big_objects, random_id
+from metricflow.plan_conversion.column_resolver import DefaultColumnAssociationResolver
 from metricflow.plan_conversion.dataflow_to_execution import DataflowToExecutionPlanConverter
 from metricflow.plan_conversion.dataflow_to_sql import DataflowToSqlQueryPlanConverter
 from metricflow.plan_conversion.time_spine import TimeSpineSource
@@ -30,8 +35,15 @@ from metricflow.sql.optimizer.optimization_levels import SqlQueryOptimizationLev
 from metricflow.time.time_source import TimeSource
 from metricflow.dataset.data_source_adapter import DataSourceDataSet
 from metricflow.errors.errors import ExecutionException, MaterializationNotFoundError
+from metricflow.sql_clients.sql_utils import make_sql_client_from_config
+from metricflow.sql_clients.common_client import not_empty
+from metricflow.telemetry.models import TelemetryLevel
+from metricflow.telemetry.reporter import TelemetryReporter, log_call
 
 logger = logging.getLogger(__name__)
+_telemetry_reporter = TelemetryReporter(report_levels_higher_or_equal_to=TelemetryLevel.USAGE)
+_telemetry_reporter.add_python_log_handler()
+_telemetry_reporter.add_rudderstack_handler()
 
 
 @dataclass(frozen=True)
@@ -74,7 +86,7 @@ class MetricFlowQueryRequest:
         limit: Optional[int] = None,
         time_constraint_start: Optional[datetime.datetime] = None,
         time_constraint_end: Optional[datetime.datetime] = None,
-        where_constraint: str = None,
+        where_constraint: Optional[str] = None,
         order_by_names: Optional[Sequence[str]] = None,
         output_table: Optional[str] = None,
         sql_optimization_level: SqlQueryOptimizationLevel = SqlQueryOptimizationLevel.O4,
@@ -146,13 +158,16 @@ class AbstractMetricFlowEngine(ABC):
         self,
         mf_request: MetricFlowQueryRequest,
     ) -> MetricFlowExplainResult:
-        """Similar to explain, but does not run the query."""
+        """Similar to query - returns the query that would have been executed."""
         pass
 
     @abstractmethod
-    def dimensions_for_metrics(self, metric_names: List[str]) -> List[Dimension]:
+    def simple_dimensions_for_metrics(self, metric_names: List[str]) -> List[Dimension]:
         """Retrieves a list of all common dimensions for metric_names.
 
+        "simple" dimensions are the ones that people expect from a UI perspective. For example, if "ds" is a time
+        dimension at a day granularity, this would not list "ds__week".
+
         Args:
             metric_names: Names of metrics to get common dimensions from.
 
@@ -193,7 +208,11 @@ class AbstractMetricFlowEngine(ABC):
 
     @abstractmethod
     def list_materializations(self) -> List[Materialization]:
-        """Retrieves a list of materialization names."""
+        """Retrieves a list of materialization names.
+
+        Returns:
+            A list of Materialization objects containing metadata.
+        """
         pass
 
     @abstractmethod
@@ -203,7 +222,9 @@ class AbstractMetricFlowEngine(ABC):
         time_constraint_start: Optional[datetime.datetime] = None,
         time_constraint_end: Optional[datetime.datetime] = None,
     ) -> SqlTable:
-        """Builds materilization. Can be very expensive if a large time range is provided.
+        """Builds a table containing metrics and dimensions from a materialization definition.
+
+        This can be very expensive if a large time range is provided.
 
         Args:
             materialization_name: Name of materialization
@@ -217,7 +238,7 @@ class AbstractMetricFlowEngine(ABC):
 
     @abstractmethod
     def drop_materialization(self, materialization_name: str) -> bool:
-        """Performs a drop materialization.
+        """Drops the table associated with a materialization definition.
 
         Args:
             materialization_name: Name of materialization to drop.
@@ -231,25 +252,50 @@ class AbstractMetricFlowEngine(ABC):
 class MetricFlowEngine(AbstractMetricFlowEngine):
     """Main entry point for queries."""
 
-    def __init__(  # noqa: D
+    _LOGGING_INDENT = "   "
+
+    @staticmethod
+    def from_config(handler: YamlFileHandler) -> MetricFlowEngine:
+        """Initialize MetricFlowEngine via yaml config file."""
+        sql_client = make_sql_client_from_config(handler)
+        semantic_model = SemanticModel(build_user_configured_model_from_config(handler))
+        system_schema = not_empty(handler.get_value(CONFIG_DWH_SCHEMA), CONFIG_DWH_SCHEMA, handler.url)
+        return MetricFlowEngine(
+            semantic_model=semantic_model,
+            sql_client=sql_client,
+            system_schema=system_schema,
+        )
+
+    def __init__(
         self,
         semantic_model: SemanticModel,
         sql_client: SqlClient,
-        column_association_resolver: ColumnAssociationResolver,
-        time_source: TimeSource,
-        time_spine_source: TimeSpineSource,
         system_schema: str,
+        time_source: TimeSource = ServerTimeSource(),
+        column_association_resolver: Optional[ColumnAssociationResolver] = None,
+        time_spine_source: Optional[TimeSpineSource] = None,
     ) -> None:
+        """Initializer for MetricFlowEngine
+
+        For direct calls to construct MetricFlowEngine, do not pass the following parameters,
+        - time_source
+        - column_association_resolver
+        - time_spine_source
+        These parameters are mainly there to be overridden during tests.
+        """
+
         self._semantic_model = semantic_model
         self._sql_client = sql_client
-        self._column_association_resolver = column_association_resolver
+        self._column_association_resolver = column_association_resolver or (
+            DefaultColumnAssociationResolver(semantic_model)
+        )
         self._time_source = time_source
-        self._time_spine_source = time_spine_source
+        self._time_spine_source = time_spine_source or TimeSpineSource(sql_client, schema_name=system_schema)
+
         self._schema = system_schema
 
         self._source_data_sets: List[DataSourceDataSet] = []
-        self._column_association_resolver = column_association_resolver
-        converter = DataSourceToDataSetConverter(column_association_resolver=column_association_resolver)
+        converter = DataSourceToDataSetConverter(column_association_resolver=self._column_association_resolver)
         for data_source in self._semantic_model.user_configured_model.data_sources:
             data_set = converter.create_sql_source_data_set(data_source)
             self._source_data_sets.append(data_set)
@@ -263,12 +309,12 @@ class MetricFlowEngine(AbstractMetricFlowEngine):
             data_sets=self._source_data_sets,
             semantic_model=self._semantic_model,
             primary_time_dimension_reference=self._primary_time_dimension_reference,
-            time_spine_source=time_spine_source,
+            time_spine_source=self._time_spine_source,
         )
         self._to_sql_query_plan_converter = DataflowToSqlQueryPlanConverter[DataSourceDataSet](
             column_association_resolver=self._column_association_resolver,
             semantic_model=self._semantic_model,
-            time_spine_source=time_spine_source,
+            time_spine_source=self._time_spine_source,
         )
         self._to_execution_plan_converter = DataflowToExecutionPlanConverter(
             sql_plan_converter=self._to_sql_query_plan_converter,
@@ -292,7 +338,12 @@ class MetricFlowEngine(AbstractMetricFlowEngine):
     def _generate_sql_table(self, table_name: str) -> SqlTable:
         return SqlTable.from_string(f"{self._schema}.{table_name}")
 
+    @log_call(module_name=__name__, telemetry_reporter=_telemetry_reporter)
     def query(self, mf_request: MetricFlowQueryRequest) -> MetricFlowQueryResult:  # noqa: D
+        logger.info(
+            f"Starting query request:\n"
+            f"{textwrap.indent(pformat_big_objects(mf_request), prefix=MetricFlowEngine._LOGGING_INDENT)}"
+        )
         explain_result = self._create_execution_plan(mf_request)
         execution_plan = explain_result.execution_plan
 
@@ -311,6 +362,8 @@ class MetricFlowEngine(AbstractMetricFlowEngine):
         task_execution_result = execution_results.get_result(task.task_id)
 
         assert task_execution_result.sql, "Task execution should have returned SQL that was run"
+
+        logger.info(f"Finished query request: {mf_request.request_id}")
         return MetricFlowQueryResult(
             query_spec=explain_result.query_spec,
             dataflow_plan=explain_result.dataflow_plan,
@@ -381,17 +434,22 @@ class MetricFlowEngine(AbstractMetricFlowEngine):
             output_table=output_table,
         )
 
+    @log_call(module_name=__name__, telemetry_reporter=_telemetry_reporter)
     def explain(self, mf_request: MetricFlowQueryRequest) -> MetricFlowExplainResult:  # noqa: D
         return self._create_execution_plan(mf_request)
 
-    def dimensions_for_metrics(self, metric_names: List[str]) -> List[Dimension]:  # noqa: D
+    def simple_dimensions_for_metrics(self, metric_names: List[str]) -> List[Dimension]:  # noqa: D
         return [
             Dimension(name=dim.qualified_name)
             for dim in self._semantic_model.metric_semantics.element_specs_for_metrics(
                 metric_specs=[MetricSpec(element_name=mname) for mname in metric_names],
+                dimensions_only=True,
+                exclude_derived_time_granularities=True,
+                exclude_local_linked_primary_time=True,
             )
         ]
 
+    @log_call(module_name=__name__, telemetry_reporter=_telemetry_reporter)
     def list_materializations(self) -> List[Materialization]:  # noqa: D
         return [
             Materialization(
@@ -400,17 +458,19 @@ class MetricFlowEngine(AbstractMetricFlowEngine):
             for mat in self._semantic_model.user_configured_model.materializations
         ]
 
+    @log_call(module_name=__name__, telemetry_reporter=_telemetry_reporter)
     def list_metrics(self) -> List[Metric]:  # noqa: D
         metric_specs = self._semantic_model.metric_semantics.metric_names
         metrics = self._semantic_model.metric_semantics.get_metrics(metric_specs)
         return [
             Metric(
                 name=metric.name,
-                dimensions=self.dimensions_for_metrics([metric.name]),
+                dimensions=self.simple_dimensions_for_metrics([metric.name]),
             )
             for metric in metrics
         ]
 
+    @log_call(module_name=__name__, telemetry_reporter=_telemetry_reporter)
     def get_dimension_values(  # noqa: D
         self,
         metric_name: str,
@@ -437,6 +497,7 @@ class MetricFlowEngine(AbstractMetricFlowEngine):
         dimension_values = [str(val) for val in result_dataframe[get_group_by_values]]
         return dimension_values
 
+    @log_call(module_name=__name__, telemetry_reporter=_telemetry_reporter)
     def materialize(  # noqa: D
         self,
         materialization_name: str,
@@ -466,6 +527,7 @@ class MetricFlowEngine(AbstractMetricFlowEngine):
         assert query_result.result_table
         return query_result.result_table
 
+    @log_call(module_name=__name__, telemetry_reporter=_telemetry_reporter)
     def drop_materialization(self, materialization_name: str) -> bool:  # noqa: D
         materialization = self._get_materialization_by_name(materialization_name)
         if materialization is None:
