@@ -1,7 +1,9 @@
 from __future__ import annotations
 
+import re
 from typing import Optional
 
+from metricflow.errors.errors import ParsingException
 from metricflow.model.objects.utils import HashableBaseModel
 from metricflow.object_utils import ExtendedEnum
 from metricflow.specs import LinkableElementReference
@@ -11,17 +13,26 @@ class Version(HashableBaseModel):  # noqa: D
     major: int
     minor: int
 
+    _VERSION_REGEX = re.compile(r"^v[0-9]+\.[0-9]+$")
+
     @staticmethod
     def parse(version: str) -> Version:  # noqa: D
+
+        if not Version._VERSION_REGEX.match(version):
+            raise ParsingException(
+                f"Expected a version of the form 'v<MAJOR_VERSION>.<MINOR_VERSION>' but got '{version}'."
+            )
         if version[0] == "v":
             version = version[1:]
 
         parts = version.split(".")
-        if len(parts) != 2:
-            raise RuntimeError(f"Invalid version string in configs: {version}")
+        assert len(parts) == 2
 
         return Version(major=int(parts[0]), minor=int(parts[1]))
 
+    def __str__(self) -> str:  # noqa: D
+        return f"{self.__class__.__name__}(major={self.major}, minor={self.minor})"
+
 
 class Element:  # noqa: D
     name: LinkableElementReference
