@@ -1,7 +1,5 @@
 from typing import Optional, TypeVar
 
-from ddtrace import Pin
-
 from metricflow.object_utils import ExtendedEnum
 
 
@@ -26,8 +24,3 @@ def not_empty(value: Optional[T], component_name: str, url: str) -> T:
         raise ValueError(f"Missing {component_name} in {url}")
     else:
         return value
-
-
-def tag_conn(dbapi_conn, connection_rec, connection_proxy) -> None:  # type: ignore
-    """Pins the provided connection as redshift."""
-    Pin.override(dbapi_conn, service=SqlDialect.REDSHIFT.value)
