@@ -232,9 +232,9 @@ def join_select_statement() -> SqlSelectStatementNode:
             ),
             SqlSelectColumn(
                 expr=SqlColumnReferenceExpression(
-                    col_ref=SqlColumnReference(table_alias="listings_src", column_name="listing__country_latest")
+                    col_ref=SqlColumnReference(table_alias="listings_src", column_name="country_latest")
                 ),
-                column_alias="ds",
+                column_alias="listing__country_latest",
             ),
             SqlSelectColumn(
                 expr=SqlColumnReferenceExpression(
@@ -405,7 +405,7 @@ def colliding_select_statement() -> SqlSelectStatementNode:
                 expr=SqlColumnReferenceExpression(
                     col_ref=SqlColumnReference(table_alias="listings_src", column_name="listing__country_latest")
                 ),
-                column_alias="ds",
+                column_alias="listing__country_latest",
             ),
             SqlSelectColumn(
                 expr=SqlColumnReferenceExpression(
@@ -533,3 +533,238 @@ def test_colliding_alias(
         sql_plan_node=sub_query_reducer.optimize(colliding_select_statement),
         plan_id="after_reducing",
     )
+
+
+@pytest.fixture
+def reduce_all_join_select_statement() -> SqlSelectStatementNode:
+    """SELECT statement with a join where all sources can be reduced.
+
+    SELECT
+      SUM(bookings_src.bookings) AS bookings
+      listings_src1.country_latest AS listing__country_latest
+      listings_src2.capacity_latest AS listing__capacity_latest
+      bookings_src.ds AS ds
+    FROM (
+      SELECT
+        fct_bookings_src.booking AS bookings
+        , fct_bookings_src.ds AS ds
+        , fct_bookings_src.listing_id AS listing
+      FROM demo.fct_bookings fct_bookings_src
+      WHERE fct_bookings_src.ds >= "2020-01-01"
+    ) bookings_src
+    JOIN (
+      SELECT
+        dim_listings_src1.country_latest AS country_latest
+        , dim_listings_src1.listing_id AS listing
+      FROM demo.dim_listings dim_listings_src1
+    ) listings_src1
+    ON bookings_src.listing = listings_src.listing
+    JOIN (
+      SELECT
+        dim_listings_src2.country_latest AS capacity_latest
+        , dim_listings_src2.listing_id AS listing
+      FROM demo.dim_listings dim_listings_src2
+    ) listings_src2
+    ON listing_src1.listing = listings_src2.listing
+    GROUP BY bookings_src.ds, listings_src1.country_latest, listings_src2.capacity_latest
+    """
+    return SqlSelectStatementNode(
+        description="query",
+        select_columns=(
+            SqlSelectColumn(
+                expr=SqlFunctionExpression(
+                    sql_function=SqlFunction.SUM,
+                    sql_function_args=[
+                        SqlColumnReferenceExpression(
+                            col_ref=SqlColumnReference(table_alias="bookings_src", column_name="bookings")
+                        )
+                    ],
+                ),
+                column_alias="bookings",
+            ),
+            SqlSelectColumn(
+                expr=SqlColumnReferenceExpression(
+                    col_ref=SqlColumnReference(table_alias="listings_src1", column_name="country_latest")
+                ),
+                column_alias="listing__country_latest",
+            ),
+            SqlSelectColumn(
+                expr=SqlColumnReferenceExpression(
+                    col_ref=SqlColumnReference(table_alias="listings_src2", column_name="capacity_latest")
+                ),
+                column_alias="listing__capacity_latest",
+            ),
+            SqlSelectColumn(
+                expr=SqlColumnReferenceExpression(
+                    col_ref=SqlColumnReference(table_alias="bookings_src", column_name="ds")
+                ),
+                column_alias="ds",
+            ),
+        ),
+        from_source=SqlSelectStatementNode(
+            description="bookings_src",
+            select_columns=(
+                SqlSelectColumn(
+                    expr=SqlColumnReferenceExpression(
+                        col_ref=SqlColumnReference(table_alias="fct_bookings_src", column_name="booking")
+                    ),
+                    column_alias="bookings",
+                ),
+                SqlSelectColumn(
+                    expr=SqlColumnReferenceExpression(
+                        col_ref=SqlColumnReference(table_alias="fct_bookings_src", column_name="ds")
+                    ),
+                    column_alias="ds",
+                ),
+                SqlSelectColumn(
+                    expr=SqlColumnReferenceExpression(
+                        col_ref=SqlColumnReference(table_alias="fct_bookings_src", column_name="listing_id")
+                    ),
+                    column_alias="listing",
+                ),
+            ),
+            from_source=SqlTableFromClauseNode(sql_table=SqlTable(schema_name="demo", table_name="fct_bookings")),
+            from_source_alias="fct_bookings_src",
+            joins_descs=(),
+            where=None,
+            group_bys=(),
+            order_bys=(),
+            limit=None,
+        ),
+        from_source_alias="bookings_src",
+        joins_descs=(
+            SqlJoinDescription(
+                right_source=SqlSelectStatementNode(
+                    description="listings_src1",
+                    select_columns=(
+                        SqlSelectColumn(
+                            expr=SqlColumnReferenceExpression(
+                                col_ref=SqlColumnReference(table_alias="dim_listings_src1", column_name="country")
+                            ),
+                            column_alias="country_latest",
+                        ),
+                        SqlSelectColumn(
+                            expr=SqlColumnReferenceExpression(
+                                col_ref=SqlColumnReference(table_alias="dim_listings_src1", column_name="listing_id")
+                            ),
+                            column_alias="listing",
+                        ),
+                    ),
+                    from_source=SqlTableFromClauseNode(
+                        sql_table=SqlTable(schema_name="demo", table_name="dim_listings")
+                    ),
+                    from_source_alias="dim_listings_src1",
+                    joins_descs=(),
+                    where=None,
+                    group_bys=(),
+                    order_bys=(),
+                    limit=None,
+                ),
+                right_source_alias="listings_src1",
+                on_condition=SqlComparisonExpression(
+                    left_expr=SqlColumnReferenceExpression(
+                        SqlColumnReference(table_alias="bookings_src", column_name="listing"),
+                    ),
+                    comparison=SqlComparison.EQUALS,
+                    right_expr=SqlColumnReferenceExpression(
+                        SqlColumnReference(table_alias="listings_src1", column_name="listing"),
+                    ),
+                ),
+                join_type=SqlJoinType.LEFT_OUTER,
+            ),
+            SqlJoinDescription(
+                right_source=SqlSelectStatementNode(
+                    description="listings_src2",
+                    select_columns=(
+                        SqlSelectColumn(
+                            expr=SqlColumnReferenceExpression(
+                                col_ref=SqlColumnReference(table_alias="dim_listings_src2", column_name="capacity")
+                            ),
+                            column_alias="capacity_latest",
+                        ),
+                        SqlSelectColumn(
+                            expr=SqlColumnReferenceExpression(
+                                col_ref=SqlColumnReference(table_alias="dim_listings_src2", column_name="listing_id")
+                            ),
+                            column_alias="listing",
+                        ),
+                    ),
+                    from_source=SqlTableFromClauseNode(
+                        sql_table=SqlTable(schema_name="demo", table_name="dim_listings")
+                    ),
+                    from_source_alias="dim_listings_src2",
+                    joins_descs=(),
+                    where=None,
+                    group_bys=(),
+                    order_bys=(),
+                    limit=None,
+                ),
+                right_source_alias="listings_src2",
+                on_condition=SqlComparisonExpression(
+                    left_expr=SqlColumnReferenceExpression(
+                        SqlColumnReference(table_alias="listings_src1", column_name="listing"),
+                    ),
+                    comparison=SqlComparison.EQUALS,
+                    right_expr=SqlColumnReferenceExpression(
+                        SqlColumnReference(table_alias="listings_src2", column_name="listing"),
+                    ),
+                ),
+                join_type=SqlJoinType.LEFT_OUTER,
+            ),
+        ),
+        group_bys=(
+            SqlSelectColumn(
+                expr=SqlColumnReferenceExpression(
+                    SqlColumnReference(
+                        table_alias="bookings_src",
+                        column_name="ds",
+                    )
+                ),
+                column_alias="ds",
+            ),
+            SqlSelectColumn(
+                expr=SqlColumnReferenceExpression(
+                    SqlColumnReference(
+                        table_alias="listings_src1",
+                        column_name="country_latest",
+                    )
+                ),
+                column_alias="listing__country_latest",
+            ),
+            SqlSelectColumn(
+                expr=SqlColumnReferenceExpression(
+                    SqlColumnReference(
+                        table_alias="listings_src2",
+                        column_name="capacity_latest",
+                    )
+                ),
+                column_alias="listing__capacity_latest",
+            ),
+        ),
+        where=None,
+        order_bys=(),
+        limit=None,
+    )
+
+
+def test_reduce_all_join_sources(
+    request: FixtureRequest,
+    mf_test_session_state: MetricFlowTestSessionState,
+    reduce_all_join_select_statement: SqlSelectStatementNode,
+) -> None:
+    """Tests a case where reducing occurs all all sources on a JOIN"""
+    assert_default_rendered_sql_equal(
+        request=request,
+        mf_test_session_state=mf_test_session_state,
+        sql_plan_node=reduce_all_join_select_statement,
+        plan_id="before_reducing",
+    )
+
+    sub_query_reducer = SqlRewritingSubQueryReducer()
+
+    assert_default_rendered_sql_equal(
+        request=request,
+        mf_test_session_state=mf_test_session_state,
+        sql_plan_node=sub_query_reducer.optimize(reduce_all_join_select_statement),
+        plan_id="after_reducing",
+    )
